@@ -15,6 +15,7 @@ from dataclasses import dataclass
 from os.path import expanduser
 from imessage_reader import common
 from imessage_reader import write_excel
+from imessage_reader import create_sqlite
 
 
 @dataclass
@@ -25,7 +26,7 @@ class MessageData:
     """
     user_id: str
     text: str
-    date: int
+    date: str
     service: str
 
     def __str__(self):
@@ -44,14 +45,6 @@ class FetchData:
     This class contains the methods for fetch, print and export the messages.
     """
 
-    def __init__(self, system=None):
-        if system is None:
-            self.operating_system = common.get_platform()
-
-    def check_system(self):
-        if self.operating_system != 'MAC':
-            sys.exit("Your operating system is not supported yet!")
-
     # The path to the iMessage database
     DB_PATH = expanduser("~") + '/Library/Messages/chat.db'
 
@@ -64,7 +57,15 @@ class FetchData:
               "FROM message " \
               "JOIN handle on message.handle_id=handle.ROWID"
 
-    def read_database(self) -> list:
+    def __init__(self, system=None):
+        if system is None:
+            self.operating_system = common.get_platform()
+
+    def _check_system(self):
+        if self.operating_system != 'MAC':
+            sys.exit("Your operating system is not supported yet!")
+
+    def _read_database(self) -> list:
         """
         Fetch data from the database and store the data in a list.
         :return: List containing the user id, the message and the service
@@ -77,7 +78,7 @@ class FetchData:
             data.append(MessageData(row[2], row[0], row[1], row[3]))
         return data
 
-    def show_user_txt(self, export: bool):
+    def show_user_txt(self, export: str):
         """
         Call fetch_message_data() method, print fetched data and export data.
         This method is for CLI usage.
@@ -85,35 +86,48 @@ class FetchData:
         """
 
         # Check the running operating system
-        self.check_system()
+        self._check_system()
 
         # Read chat.db
-        fetched_data = self.read_database()
+        fetched_data = self._read_database()
 
         # CLI output
         for data in fetched_data:
             print(data)
 
         # Excel export
-        if export is True:
-            self.export_data(fetched_data)
+        if export == 'excel':
+            self._export_excel(fetched_data)
 
-    def export_data(self, data: list):
+        # SQLite3 export
+        if export == 'sqlite':
+            self._export_sqlite(fetched_data)
+
+    def _export_excel(self, data: list):
         """
         Export data (write Excel file)
-        This method is for CLI usage.
         :param data: imessage objects containing user id, message and service
         """
         file_path = expanduser("~") + '/Desktop/'
         ew = write_excel.ExelWriter(data, file_path)
         ew.write_data()
 
+    def _export_sqlite(self, data: list):
+        """
+        Export data (create SQLite3 database)
+        :param data: imessage objects containig user id, message and service
+        """
+        file_path = expanduser("~") + '/Desktop/'
+        cd = create_sqlite.CreateDatabase(data, file_path)
+        cd.create_sqlite_db()
+
     def get_messages(self) -> list:
         """
-        Create a list with tuples (user id, message, service)
-        :return: List with tuples (user id, message, service)
+        Create a list with tuples (user id, message, date, service)
+        This method is for CLI usage.
+        :return: List with tuples (user id, message, date, service)
         """
-        fetched_data = self.read_database()
+        fetched_data = self._read_database()
 
         users = []
         messages = []
